==> jc-1.4.0.tar.gz: soot/jimple/parser/node/AInterfaceNonstaticInvoke.h <==
// public final class soot.jimple.parser.node.AInterfaceNonstaticInvoke

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 831afeabd0476cb5 soot_jimple_parser_node_AInterfaceNonstaticInvoke
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class d4ca50e4d96c30c8 soot_jimple_parser_node_PNonstaticInvoke

// header file dependencies
// @dep_header soot_jimple_parser_node_PNonstaticInvoke

#include "soot/jimple/parser/node/PNonstaticInvoke.h"

#ifndef _JC_soot_jimple_parser_node_AInterfaceNonstaticInvoke_H_
#define _JC_soot_jimple_parser_node_AInterfaceNonstaticInvoke_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_Switch$object;
struct _jc_soot_jimple_parser_node_TInterfaceinvoke$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_AInterfaceNonstaticInvoke$sub_refs	_jc_soot_jimple_parser_node_AInterfaceNonstaticInvoke$sub_refs;
typedef struct _jc_soot_jimple_parser_node_AInterfaceNonstaticInvoke$sub_nonrefs	_jc_soot_jimple_parser_node_AInterfaceNonstaticInvoke$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_AInterfaceNonstaticInvoke$refs	_jc_soot_jimple_parser_node_AInterfaceNonstaticInvoke$refs;
typedef struct _jc_soot_jimple_parser_node_AInterfaceNonstaticInvoke$nonrefs	_jc_soot_jimple_parser_node_AInterfaceNonstaticInvoke$nonrefs;
typedef struct _jc_soot_jimple_parser_node_AInterfaceNonstaticInvoke$object	_jc_soot_jimple_parser_node_AInterfaceNonstaticInvoke$object;

typedef const struct _jc_soot_jimple_parser_node_AInterfaceNonstaticInvoke$vmethods	_jc_soot_jimple_parser_node_AInterfaceNonstaticInvoke$vmethods;
typedef const struct _jc_soot_jimple_parser_node_AInterfaceNonstaticInvoke$vtable	_jc_soot_jimple_parser_node_AInterfaceNonstaticInvoke$vtable;
typedef const struct _jc_soot_jimple_parser_node_AInterfaceNonstaticInvoke$vtype	_jc_soot_jimple_parser_node_AInterfaceNonstaticInvoke$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_AInterfaceNonstaticInvoke$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_AInterfaceNonstaticInvoke$object *);
extern void _jc_soot_jimple_parser_node_AInterfaceNonstaticInvoke$method$_init$f1fae0dd378eb253(_jc_env *, struct _jc_soot_jimple_parser_node_AInterfaceNonstaticInvoke$object *, struct _jc_soot_jimple_parser_node_TInterfaceinvoke$object *);

// Virtual methods
extern void _jc_soot_jimple_parser_node_AInterfaceNonstaticInvoke$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_AInterfaceNonstaticInvoke$object *, struct _jc_object *);
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_AInterfaceNonstaticInvoke$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_AInterfaceNonstaticInvoke$object *);
extern struct _jc_soot_jimple_parser_node_TInterfaceinvoke$object *_jc_soot_jimple_parser_node_AInterfaceNonstaticInvoke$method$getInterfaceinvoke$9a0a0a4b2e993e38(_jc_env *, struct _jc_soot_jimple_parser_node_AInterfaceNonstaticInvoke$object *);
extern void _jc_soot_jimple_parser_node_AInterfaceNonstaticInvoke$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_AInterfaceNonstaticInvoke$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_AInterfaceNonstaticInvoke$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_AInterfaceNonstaticInvoke$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_AInterfaceNonstaticInvoke$method$setInterfaceinvoke$37820f2005d2a72a(_jc_env *, struct _jc_soot_jimple_parser_node_AInterfaceNonstaticInvoke$object *, struct _jc_soot_jimple_parser_node_TInterfaceinvoke$object *);
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_AInterfaceNonstaticInvoke$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_AInterfaceNonstaticInvoke$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_AInterfaceNonstaticInvoke$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_AInterfaceNonstaticInvoke$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_AInterfaceNonstaticInvoke$method_info$getInterfaceinvoke$9a0a0a4b2e993e38;
extern _jc_method _jc_soot_jimple_parser_node_AInterfaceNonstaticInvoke$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_AInterfaceNonstaticInvoke$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_AInterfaceNonstaticInvoke$method_info$setInterfaceinvoke$37820f2005d2a72a;
extern _jc_method _jc_soot_jimple_parser_node_AInterfaceNonstaticInvoke$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_AInterfaceNonstaticInvoke$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_AInterfaceNonstaticInvoke$object *, struct _jc_object *);
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_AInterfaceNonstaticInvoke$object *);
	struct _jc_soot_jimple_parser_node_TInterfaceinvoke$object	*(*getInterfaceinvoke$9a0a0a4b2e993e38)(_jc_env *, struct _jc_soot_jimple_parser_node_AInterfaceNonstaticInvoke$object *);
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_AInterfaceNonstaticInvoke$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_AInterfaceNonstaticInvoke$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*setInterfaceinvoke$37820f2005d2a72a)(_jc_env *, struct _jc_soot_jimple_parser_node_AInterfaceNonstaticInvoke$object *, struct _jc_soot_jimple_parser_node_TInterfaceinvoke$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_AInterfaceNonstaticInvoke$object *);
};

// Vtable
struct _jc_soot_jimple_parser_node_AInterfaceNonstaticInvoke$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PNonstaticInvoke$vmethods	soot_jimple_parser_node_PNonstaticInvoke;
	_jc_soot_jimple_parser_node_AInterfaceNonstaticInvoke$vmethods	soot_jimple_parser_node_AInterfaceNonstaticInvoke;
};

// Vtype
struct _jc_soot_jimple_parser_node_AInterfaceNonstaticInvoke$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_AInterfaceNonstaticInvoke$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AInterfaceNonstaticInvoke$sub_refs {
	struct _jc_soot_jimple_parser_node_TInterfaceinvoke$object	*__5finterfaceinvoke__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_AInterfaceNonstaticInvoke$refs {
    _jc_soot_jimple_parser_node_AInterfaceNonstaticInvoke$sub_refs	soot_jimple_parser_node_AInterfaceNonstaticInvoke;
    _jc_soot_jimple_parser_node_PNonstaticInvoke$sub_refs	soot_jimple_parser_node_PNonstaticInvoke;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AInterfaceNonstaticInvoke$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_AInterfaceNonstaticInvoke$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PNonstaticInvoke$sub_nonrefs	soot_jimple_parser_node_PNonstaticInvoke;
    _jc_soot_jimple_parser_node_AInterfaceNonstaticInvoke$sub_nonrefs	soot_jimple_parser_node_AInterfaceNonstaticInvoke;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_AInterfaceNonstaticInvoke$object {
	_jc_soot_jimple_parser_node_AInterfaceNonstaticInvoke$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_AInterfaceNonstaticInvoke$vtype	*vtype;
	_jc_soot_jimple_parser_node_AInterfaceNonstaticInvoke$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_AInterfaceNonstaticInvoke$vtype _jc_soot_jimple_parser_node_AInterfaceNonstaticInvoke$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_AInterfaceNonstaticInvoke, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_AInterfaceNonstaticInvoke$class_object;

#endif	/* _JC_soot_jimple_parser_node_AInterfaceNonstaticInvoke_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/parser/node/AInterfaceNonstaticInvoke.h <==
// public final class soot.jimple.parser.node.AInterfaceNonstaticInvoke

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 831afeabd0476cb5 soot_jimple_parser_node_AInterfaceNonstaticInvoke
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class d4ca50e4d96c30c8 soot_jimple_parser_node_PNonstaticInvoke

// header file dependencies
// @dep_header soot_jimple_parser_node_PNonstaticInvoke

#include "soot/jimple/parser/node/PNonstaticInvoke.h"

#ifndef _JC_soot_jimple_parser_node_AInterfaceNonstaticInvoke_H_
#define _JC_soot_jimple_parser_node_AInterfaceNonstaticInvoke_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_Switch$object;
struct _jc_soot_jimple_parser_node_TInterfaceinvoke$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_AInterfaceNonstaticInvoke$sub_refs	_jc_soot_jimple_parser_node_AInterfaceNonstaticInvoke$sub_refs;
typedef struct _jc_soot_jimple_parser_node_AInterfaceNonstaticInvoke$sub_nonrefs	_jc_soot_jimple_parser_node_AInterfaceNonstaticInvoke$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_AInterfaceNonstaticInvoke$refs	_jc_soot_jimple_parser_node_AInterfaceNonstaticInvoke$refs;
typedef struct _jc_soot_jimple_parser_node_AInterfaceNonstaticInvoke$nonrefs	_jc_soot_jimple_parser_node_AInterfaceNonstaticInvoke$nonrefs;
typedef struct _jc_soot_jimple_parser_node_AInterfaceNonstaticInvoke$object	_jc_soot_jimple_parser_node_AInterfaceNonstaticInvoke$object;

typedef const struct _jc_soot_jimple_parser_node_AInterfaceNonstaticInvoke$vmethods	_jc_soot_jimple_parser_node_AInterfaceNonstaticInvoke$vmethods;
typedef const struct _jc_soot_jimple_parser_node_AInterfaceNonstaticInvoke$vtable	_jc_soot_jimple_parser_node_AInterfaceNonstaticInvoke$vtable;
typedef const struct _jc_soot_jimple_parser_node_AInterfaceNonstaticInvoke$vtype	_jc_soot_jimple_parser_node_AInterfaceNonstaticInvoke$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_AInterfaceNonstaticInvoke$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_AInterfaceNonstaticInvoke$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AInterfaceNonstaticInvoke$method$_init$f1fae0dd378eb253(_jc_env *, struct _jc_soot_jimple_parser_node_AInterfaceNonstaticInvoke$object *, struct _jc_soot_jimple_parser_node_TInterfaceinvoke$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_parser_node_AInterfaceNonstaticInvoke$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_AInterfaceNonstaticInvoke$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_AInterfaceNonstaticInvoke$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_AInterfaceNonstaticInvoke$object *) _JC_JCNI_ATTR;
extern struct _jc_soot_jimple_parser_node_TInterfaceinvoke$object *_jc_soot_jimple_parser_node_AInterfaceNonstaticInvoke$method$getInterfaceinvoke$9a0a0a4b2e993e38(_jc_env *, struct _jc_soot_jimple_parser_node_AInterfaceNonstaticInvoke$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AInterfaceNonstaticInvoke$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_AInterfaceNonstaticInvoke$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AInterfaceNonstaticInvoke$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_AInterfaceNonstaticInvoke$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AInterfaceNonstaticInvoke$method$setInterfaceinvoke$37820f2005d2a72a(_jc_env *, struct _jc_soot_jimple_parser_node_AInterfaceNonstaticInvoke$object *, struct _jc_soot_jimple_parser_node_TInterfaceinvoke$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_AInterfaceNonstaticInvoke$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_AInterfaceNonstaticInvoke$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_AInterfaceNonstaticInvoke$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_AInterfaceNonstaticInvoke$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_AInterfaceNonstaticInvoke$method_info$getInterfaceinvoke$9a0a0a4b2e993e38;
extern _jc_method _jc_soot_jimple_parser_node_AInterfaceNonstaticInvoke$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_AInterfaceNonstaticInvoke$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_AInterfaceNonstaticInvoke$method_info$setInterfaceinvoke$37820f2005d2a72a;
extern _jc_method _jc_soot_jimple_parser_node_AInterfaceNonstaticInvoke$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_AInterfaceNonstaticInvoke$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_AInterfaceNonstaticInvoke$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_AInterfaceNonstaticInvoke$object *) _JC_JCNI_ATTR;
	struct _jc_soot_jimple_parser_node_TInterfaceinvoke$object	*(*getInterfaceinvoke$9a0a0a4b2e993e38)(_jc_env *, struct _jc_soot_jimple_parser_node_AInterfaceNonstaticInvoke$object *) _JC_JCNI_ATTR;
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_AInterfaceNonstaticInvoke$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_AInterfaceNonstaticInvoke$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*setInterfaceinvoke$37820f2005d2a72a)(_jc_env *, struct _jc_soot_jimple_parser_node_AInterfaceNonstaticInvoke$object *, struct _jc_soot_jimple_parser_node_TInterfaceinvoke$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_AInterfaceNonstaticInvoke$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_parser_node_AInterfaceNonstaticInvoke$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PNonstaticInvoke$vmethods	soot_jimple_parser_node_PNonstaticInvoke;
	_jc_soot_jimple_parser_node_AInterfaceNonstaticInvoke$vmethods	soot_jimple_parser_node_AInterfaceNonstaticInvoke;
};

// Vtype
struct _jc_soot_jimple_parser_node_AInterfaceNonstaticInvoke$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_AInterfaceNonstaticInvoke$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AInterfaceNonstaticInvoke$sub_refs {
	struct _jc_soot_jimple_parser_node_TInterfaceinvoke$object	*__5finterfaceinvoke__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_AInterfaceNonstaticInvoke$refs {
    _jc_soot_jimple_parser_node_AInterfaceNonstaticInvoke$sub_refs	soot_jimple_parser_node_AInterfaceNonstaticInvoke;
    _jc_soot_jimple_parser_node_PNonstaticInvoke$sub_refs	soot_jimple_parser_node_PNonstaticInvoke;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AInterfaceNonstaticInvoke$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_AInterfaceNonstaticInvoke$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PNonstaticInvoke$sub_nonrefs	soot_jimple_parser_node_PNonstaticInvoke;
    _jc_soot_jimple_parser_node_AInterfaceNonstaticInvoke$sub_nonrefs	soot_jimple_parser_node_AInterfaceNonstaticInvoke;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_AInterfaceNonstaticInvoke$object {
	_jc_soot_jimple_parser_node_AInterfaceNonstaticInvoke$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_AInterfaceNonstaticInvoke$vtype	*vtype;
	_jc_soot_jimple_parser_node_AInterfaceNonstaticInvoke$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_AInterfaceNonstaticInvoke$vtype _jc_soot_jimple_parser_node_AInterfaceNonstaticInvoke$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_AInterfaceNonstaticInvoke, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_AInterfaceNonstaticInvoke$class_object;

#endif	/* _JC_soot_jimple_parser_node_AInterfaceNonstaticInvoke_H_ */
